#  WakeOnLAN-API

[![PyPI version](https://badge.fury.io/py/wol_api.svg)](https://badge.fury.io/py/wol_api)
[![Github Sponsorship](https://img.shields.io/badge/support-me-red.svg)](https://github.com/users/rix1337/sponsorship)

A simple flask interface to send wake on LAN commands. Just send a `POST` to `/ff.ff.ff.ff.ff.ff`

The official docker image is available at [Docker Hub](https://hub.docker.com/r/rix1337/docker-wol_api).

# Setup

`pip install wol_api`

# Run

` wol_api --port=8080` 

